@@ -81,8 +81,6 @@ def dimensionless_batch(
     max_batch_size: int = DEFAULT_MAX_BATCH_SIZE
 ) -> List[Batch]:
     '''Batch records in groups of max_batch_size ignoring dimensions and dimension commonalities'''
-    max_batch_size = max_batch_size or DEFAULT_MAX_BATCH_SIZE
-    assert isinstance(max_batch_size, int), f'Invalid max batch size: {max_batch_size}'
     batches = []
     for i in range(0, len(records), max_batch_size):
         batches.append(Batch(
